﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Mvc;
using Sample.Models;
using Syncfusion.Presentation;

namespace Sample.Controllers
{
    public class HomeController : Controller
    {

        private readonly IHostingEnvironment _hostingEnvironment;
        public HomeController(IHostingEnvironment hostingEnvironment)
        {
            _hostingEnvironment = hostingEnvironment;
        }
        public IActionResult Index()
        {
            return View();
        }

        [HttpPost]

        public IActionResult CreatePresentation()
        {

            //Creates PowerPoint Presentation
            IPresentation pptxDoc = Presentation.Create();

            //Adds slide to the PowerPoint
            ISlide slide = pptxDoc.Slides.Add(SlideLayoutType.Blank);

            //Adds textbox to the slide
            IShape textboxShape = slide.AddTextBox(0, 0, 500, 500);

            //Adds paragraph to the textbody of textbox
            IParagraph paragraph = textboxShape.TextBody.AddParagraph();

            //Adds a TextPart to the paragraph
            ITextPart textPart = paragraph.AddTextPart();

            //Adds text to the TextPart
            textPart.Text = "AdventureWorks Cycles, the fictitious company on which the AdventureWorks sample databases are based, is a large, multinational manufacturing company. The company manufactures and sells metal and composite bicycles to North American, European and Asian commercial markets. While its base operation is located in Washington with 290 employees, several regional sales teams are located throughout their market base.";

            //Create new insntnace of memory stream.
            MemoryStream stream = new MemoryStream();

            pptxDoc.Save(stream);

            stream.Position = 0;

            //Close the presentation instance.
            pptxDoc.Close();

            //Initialize the file stream to download the converted PDF.
            FileStreamResult fileStreamResult = new FileStreamResult(stream, "application/vnd.openxmlformats-officedocument.presentationml.presentation");

            fileStreamResult.FileDownloadName = "output.pptx";


            //Set the file name.
            return fileStreamResult;
        }

        public IActionResult About()
        {
            ViewData["Message"] = "Your application description page.";

            return View();
        }

        public IActionResult Contact()
        {
            ViewData["Message"] = "Your contact page.";

            return View();
        }

        public IActionResult Error()
        {
            return View(new ErrorViewModel { RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier });
        }
    }
}
